@@ -3,9 +3,10 @@ use nom::branch::alt;
 use nom::bytes::complete::{is_not, tag, take_until};
 use nom::character::complete;
 use nom::character::complete::char;
-use nom::combinator::recognize;
+use nom::combinator::{opt, recognize};
 use nom::error::ParseError;
 use nom::error::VerboseError;
+use nom::sequence::tuple;
 use nom::{combinator, sequence, IResult};
 use petgraph::prelude::*;
 
@@ -167,13 +168,10 @@ impl<'input> Version<'input> {
 
 impl<'input> From<&'input str> for Conf<'input> {
     fn from(s: &'input str) -> Self {
-        let mut parts = s.split('|');
-        let config = parts.next().unwrap_or_default();
-        let platform = parts.next().unwrap_or_default();
-        if config.is_empty() || platform.is_empty() || parts.next().is_some() {
-            Default::default()
-        } else {
-            Self { config, platform }
+        let r = configuration::<VerboseError<&str>>(s);
+        match r {
+            Ok((platform, config)) => Self { config, platform },
+            _ => Default::default(),
         }
     }
 }
@@ -196,12 +194,20 @@ impl<'input> Conf<'input> {
     }
 }
 
+#[derive(Default, PartialEq, Debug)]
+struct ProjectConfig<'input> {
+    id: &'input str,
+    configuration: &'input str,
+    platform: &'input str,
+}
+
 impl<'input> From<&'input str> for ProjectConfigs<'input> {
-    fn from(s: &'input str) -> Self {
+    fn from(k: &'input str) -> Self {
         let (_, project_config) =
-            ProjectConfigs::parse::<VerboseError<&str>>(s).unwrap_or_default();
+            ProjectConfigs::parse::<VerboseError<&str>>(k).unwrap_or_default();
 
         let mut configs = Vec::new();
+
         let config = Conf::new(project_config.configuration, project_config.platform);
         configs.push(config);
         Self {
@@ -211,13 +217,6 @@ impl<'input> From<&'input str> for ProjectConfigs<'input> {
     }
 }
 
-#[derive(Default, PartialEq, Debug)]
-struct ProjectConfig<'input> {
-    id: &'input str,
-    configuration: &'input str,
-    platform: &'input str,
-}
-
 impl<'input> ProjectConfigs<'input> {
     pub fn from_id_and_configs(project_id: &'input str, configs: Vec<Conf<'input>>) -> Self {
         let mut configurations = Vec::new();
@@ -241,45 +240,54 @@ impl<'input> ProjectConfigs<'input> {
     where
         E: ParseError<&'a str> + std::fmt::Debug,
     {
-        let parser = sequence::separated_pair(
-            ProjectConfigs::id_and_configuration,
-            char('|'),
-            ProjectConfigs::platform,
-        );
-        combinator::map(parser, |((project_id, config), platform)| ProjectConfig {
-            id: project_id,
-            configuration: config,
-            platform,
+        let parser =
+            sequence::separated_pair(guid, char('.'), tuple((opt(configuration), platform)));
+
+        combinator::map(parser, |(project_id, (config, platform))| match config {
+            None => ProjectConfig {
+                id: project_id,
+                configuration: platform,
+                platform: "",
+            },
+            Some(c) => ProjectConfig {
+                id: project_id,
+                configuration: c,
+                platform,
+            },
         })(input)
     }
+}
 
-    fn guid<'a, E>(input: &'a str) -> IResult<&'a str, &'a str, E>
-    where
-        E: ParseError<&'a str> + std::fmt::Debug,
-    {
-        recognize(sequence::delimited(
-            complete::char('{'),
-            is_not("{}"),
-            complete::char('}'),
-        ))(input)
-    }
+fn guid<'a, E>(input: &'a str) -> IResult<&'a str, &'a str, E>
+where
+    E: ParseError<&'a str> + std::fmt::Debug,
+{
+    recognize(sequence::delimited(
+        complete::char('{'),
+        is_not("{}"),
+        complete::char('}'),
+    ))(input)
+}
 
-    fn id_and_configuration<'a, E>(input: &'a str) -> IResult<&'a str, (&'a str, &'a str), E>
-    where
-        E: ParseError<&'a str> + std::fmt::Debug,
-    {
-        sequence::separated_pair(ProjectConfigs::guid, char('.'), is_not("|"))(input)
-    }
+fn platform<'a, E>(input: &'a str) -> IResult<&'a str, &'a str, E>
+where
+    E: ParseError<&'a str> + std::fmt::Debug,
+{
+    sequence::terminated(
+        alt((
+            take_until(".ActiveCfg"),
+            take_until(".Build.0"),
+            take_until(".Deploy.0"),
+        )),
+        alt((tag(".ActiveCfg"), tag(".Build.0"), tag(".Deploy.0"))),
+    )(input)
+}
 
-    fn platform<'a, E>(input: &'a str) -> IResult<&'a str, &'a str, E>
-    where
-        E: ParseError<&'a str> + std::fmt::Debug,
-    {
-        sequence::terminated(
-            alt((take_until(".ActiveCfg"), take_until(".Build.0"))),
-            alt((tag(".ActiveCfg"), tag(".Build.0"))),
-        )(input)
-    }
+fn configuration<'a, E>(input: &'a str) -> IResult<&'a str, &'a str, E>
+where
+    E: ParseError<&'a str> + std::fmt::Debug,
+{
+    sequence::terminated(is_not("|"), char('|'))(input)
 }
 
 #[cfg(test)]
@@ -288,56 +296,20 @@ mod tests {
     use rstest::*;
     use spectral::prelude::*;
 
-    #[test]
-    fn from_configuration_correct() {
+    #[rstest]
+    #[case("Release|Any CPU", Conf { config: "Release", platform: "Any CPU" })]
+    #[case("", Conf { config: "", platform: "" })]
+    #[case("Release Any CPU", Conf { config: "", platform: "" })]
+    #[case("Release|Any CPU|test", Conf { config: "Release", platform: "Any CPU|test" })]
+    #[trace]
+    fn from_configuration_tests(#[case] i: &str, #[case] expected: Conf) {
         // Arrange
-        let s = "Release|Any CPU";
 
         // Act
-        let c = Conf::from(s);
+        let c = Conf::from(i);
 
         // Assert
-        assert_that!(c.config).is_equal_to("Release");
-        assert_that!(c.platform).is_equal_to("Any CPU");
-    }
-
-    #[test]
-    fn from_configuration_empty() {
-        // Arrange
-        let s = "";
-
-        // Act
-        let c = Conf::from(s);
-
-        // Assert
-        assert_that!(c.config).is_equal_to("");
-        assert_that!(c.platform).is_equal_to("");
-    }
-
-    #[test]
-    fn from_configuration_incorrect_no_pipe() {
-        // Arrange
-        let s = "Release Any CPU";
-
-        // Act
-        let c = Conf::from(s);
-
-        // Assert
-        assert_that!(c.config).is_equal_to("");
-        assert_that!(c.platform).is_equal_to("");
-    }
-
-    #[test]
-    fn from_configuration_incorrect_many_pipes() {
-        // Arrange
-        let s = "Release|Any CPU|test";
-
-        // Act
-        let c = Conf::from(s);
-
-        // Assert
-        assert_that!(c.config).is_equal_to("");
-        assert_that!(c.platform).is_equal_to("");
+        assert_that!(c).is_equal_to(expected);
     }
 
     #[test]
@@ -386,18 +358,18 @@ mod tests {
     }
 
     #[test]
-    fn from_project_configurations_platform_with_dot_build() {
+    fn from_project_configurations_without_platform() {
         // Arrange
-        let s = "{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}.Release|.NET.Build.0";
+        let s = "{5228E9CE-A216-422F-A5E6-58E95E2DD71D}.DLL Debug.ActiveCfg";
 
         // Act
         let c = ProjectConfigs::from(s);
 
         // Assert
-        assert_that!(c.project_id).is_equal_to("{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}");
+        assert_that!(c.project_id).is_equal_to("{5228E9CE-A216-422F-A5E6-58E95E2DD71D}");
         assert_that!(c.configs).has_length(1);
-        assert_that!(c.configs[0].config).is_equal_to("Release");
-        assert_that!(c.configs[0].platform).is_equal_to(".NET");
+        assert_that!(c.configs[0].config).is_equal_to("DLL Debug");
+        assert_that!(c.configs[0].platform).is_equal_to("");
     }
 
     #[test]
@@ -406,7 +378,7 @@ mod tests {
         let s = "{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}.Release|.NET.Build.0";
 
         // Act
-        let result = ProjectConfigs::guid::<VerboseError<&str>>(s);
+        let result = guid::<VerboseError<&str>>(s);
 
         // Assert
         assert_that!(result).is_equal_to(Ok((
@@ -419,11 +391,11 @@ mod tests {
     #[case(".NET.Build.0", ".NET")]
     #[case(".NET.ActiveCfg", ".NET")]
     #[trace]
-    fn cfg_tests(#[case] i: &str, #[case] expected: &str) {
+    fn platform_tests(#[case] i: &str, #[case] expected: &str) {
         // Arrange
 
         // Act
-        let result = ProjectConfigs::platform::<VerboseError<&str>>(i);
+        let result = platform::<VerboseError<&str>>(i);
 
         // Assert
         assert_that!(result).is_equal_to(Ok(("", expected)));
@@ -431,7 +403,9 @@ mod tests {
 
     #[rstest]
     #[case("{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}.Release|.NET.Build.0", ProjectConfig { id: "{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}", configuration: "Release", platform: ".NET" })]
+    #[case("{60BB14A5-0871-4656-BC38-4F0958230F9A}.Debug|ARM.Deploy.0", ProjectConfig { id: "{60BB14A5-0871-4656-BC38-4F0958230F9A}", configuration: "Debug", platform: "ARM" })]
     #[case("{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}.Release|.NET.ActiveCfg", ProjectConfig { id: "{7C2EF610-BCA0-4D1F-898A-DE9908E4970C}", configuration: "Release", platform: ".NET" })]
+    #[case("{5228E9CE-A216-422F-A5E6-58E95E2DD71D}.DLL Debug.ActiveCfg", ProjectConfig { id: "{5228E9CE-A216-422F-A5E6-58E95E2DD71D}", configuration: "DLL Debug", platform: "" })]
     #[trace]
     fn project_configs_parse_tests(#[case] i: &str, #[case] expected: ProjectConfig) {
         // Arrange
