@@ -86,15 +86,28 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                 sol.versions.push(version);
             }
             Expr::Global(sections) => {
-                let solution_configs = sections
+                let configs_and_platforms = sections
                     .iter()
                     .filter_map(|sect| section_content!(sect, "SolutionConfigurationPlatforms"))
                     .flatten()
                     .filter_map(|expr| Conf::from_expr(expr));
 
-                sol.solution_configs.extend(solution_configs);
+                let only_configs = sections
+                    .iter()
+                    .filter_map(|sect| section_content!(sect, "SolutionConfiguration"))
+                    .flatten()
+                    .filter_map(|expr| {
+                        if let Expr::SectionContent(_, right) = expr {
+                            let conf = Conf::new(right.string(), "");
+                            return Some(conf);
+                        }
+                        None
+                    });
 
-                let project_configs = sections
+                sol.solution_configs.extend(configs_and_platforms);
+                sol.solution_configs.extend(only_configs);
+
+                let project_configs_platforms = sections
                     .iter()
                     .filter_map(|sect| section_content!(sect, "ProjectConfigurationPlatforms"))
                     .flatten()
@@ -107,6 +120,20 @@ fn analyze<'input>(solution: (Expr<'input>, Vec<Expr<'input>>)) -> Solution<'inp
                     })
                     .collect::<Vec<ProjectConfigs<'input>>>();
 
+                let project_configs = sections
+                    .iter()
+                    .filter_map(|sect| section_content!(sect, "ProjectConfiguration"))
+                    .flatten()
+                    .filter_map(|expr| ProjectConfigs::new(expr))
+                    .group_by(|x| x.project_id)
+                    .into_iter()
+                    .map(|(pid, project_configs)| {
+                        let c = project_configs.map(|c| c.configs).flatten().collect();
+                        ProjectConfigs::from_id_and_configs(pid, c)
+                    })
+                    .collect::<Vec<ProjectConfigs<'input>>>();
+
+                sol.project_configs.extend(project_configs_platforms);
                 sol.project_configs.extend(project_configs);
             }
             Expr::Comment(s) => sol.product = s,
@@ -171,7 +198,7 @@ EndGlobal
         let sln = parse_str(input, false);
 
         // Assert
-        assert_that(&sln).is_none();
+        assert_that!(sln).is_none();
     }
 
     #[test]
@@ -183,7 +210,18 @@ EndGlobal
         let sln = parse_str(input, false);
 
         // Assert
-        assert_that(&sln).is_none();
+        assert_that!(sln).is_none();
+    }
+
+    #[test]
+    fn parser_version8_solution() {
+        // Arrange
+
+        // Act
+        let sln = parse_str(VERSION8_SOLUTION, false);
+
+        // Assert
+        assert_that!(sln).is_some();
     }
 
     const REAL_SOLUTION: &str = r#"
@@ -332,4 +370,52 @@ Global
 	EndGlobalSection
 EndGlobal
 "#;
+
+    const VERSION8_SOLUTION: &str = r###"
+Microsoft Visual Studio Solution File, Format Version 8.00
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "gtest", "gtest.vcproj", "{C8F6C172-56F2-4E76-B5FA-C3B423B31BE7}"
+	ProjectSection(ProjectDependencies) = postProject
+	EndProjectSection
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "gtest_main", "gtest_main.vcproj", "{3AF54C8A-10BF-4332-9147-F68ED9862032}"
+	ProjectSection(ProjectDependencies) = postProject
+	EndProjectSection
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "gtest_unittest", "gtest_unittest.vcproj", "{4D9FDFB5-986A-4139-823C-F4EE0ED481A1}"
+	ProjectSection(ProjectDependencies) = postProject
+	EndProjectSection
+EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "gtest_prod_test", "gtest_prod_test.vcproj", "{24848551-EF4F-47E8-9A9D-EA4D49BC3ECA}"
+	ProjectSection(ProjectDependencies) = postProject
+	EndProjectSection
+EndProject
+Global
+	GlobalSection(SolutionConfiguration) = preSolution
+		Debug = Debug
+		Release = Release
+	EndGlobalSection
+	GlobalSection(ProjectConfiguration) = postSolution
+		{C8F6C172-56F2-4E76-B5FA-C3B423B31BE7}.Debug.ActiveCfg = Debug|Win32
+		{C8F6C172-56F2-4E76-B5FA-C3B423B31BE7}.Debug.Build.0 = Debug|Win32
+		{C8F6C172-56F2-4E76-B5FA-C3B423B31BE7}.Release.ActiveCfg = Release|Win32
+		{C8F6C172-56F2-4E76-B5FA-C3B423B31BE7}.Release.Build.0 = Release|Win32
+		{3AF54C8A-10BF-4332-9147-F68ED9862032}.Debug.ActiveCfg = Debug|Win32
+		{3AF54C8A-10BF-4332-9147-F68ED9862032}.Debug.Build.0 = Debug|Win32
+		{3AF54C8A-10BF-4332-9147-F68ED9862032}.Release.ActiveCfg = Release|Win32
+		{3AF54C8A-10BF-4332-9147-F68ED9862032}.Release.Build.0 = Release|Win32
+		{4D9FDFB5-986A-4139-823C-F4EE0ED481A1}.Debug.ActiveCfg = Debug|Win32
+		{4D9FDFB5-986A-4139-823C-F4EE0ED481A1}.Debug.Build.0 = Debug|Win32
+		{4D9FDFB5-986A-4139-823C-F4EE0ED481A1}.Release.ActiveCfg = Release|Win32
+		{4D9FDFB5-986A-4139-823C-F4EE0ED481A1}.Release.Build.0 = Release|Win32
+		{24848551-EF4F-47E8-9A9D-EA4D49BC3ECA}.Debug.ActiveCfg = Debug|Win32
+		{24848551-EF4F-47E8-9A9D-EA4D49BC3ECA}.Debug.Build.0 = Debug|Win32
+		{24848551-EF4F-47E8-9A9D-EA4D49BC3ECA}.Release.ActiveCfg = Release|Win32
+		{24848551-EF4F-47E8-9A9D-EA4D49BC3ECA}.Release.Build.0 = Release|Win32
+	EndGlobalSection
+	GlobalSection(ExtensibilityGlobals) = postSolution
+	EndGlobalSection
+	GlobalSection(ExtensibilityAddIns) = postSolution
+	EndGlobalSection
+EndGlobal
+"###;
 }
